function [x,y]=bfeuler(fun,x0,xf,y0,Nh)
% -----------------------------------------------------
% FEULER: Resuelve ecuaciones diferenciales del tipo
% y' = f(x,y) usando el
% mtodo de Euler implcito utilizando una malla
% equiespaciada con Nh intervalos.
%
% IMPORTANTE: Requiere usar la funcin fsolve que est en la
% OPTIMIZATION TOOLBOX (una extensin de Matlab)
%
% PARMETROS DE ENTRADA:
% fun: funcin annima (puntero a funcin). Es importante que la funcin est definida como
% una funcin de dos variables f(x,y;k1,k2,..,kn) por este orden.
% k1,k2,..,kn son todos los otros parmetros que puede haber en la funcin
% y a los que tenemos que dar valores al definir la funcin annima.
% x0: valor inicial de la variable independiente
% xf: valor final de la variable independiente
% y0: variable con el valor inicial de y
% Nh: nmero de intervalos que tomamos entre el instante inicial y final.
% Por ejemplo, si Nh=3, dividimos el tiempo entre el instante inicial y el
% final en tres intervalos.
%
% PARMETROS DE SALIDA:
% x: vector columna con los valores de la variable independiente en los que se ha
% evaluado y.
% y: vector columna con lo valores de la funcin y
% -----------------------------------------------------
h=(xf-x0)/Nh;
x=zeros(1,Nh+1);
y=zeros(1,Nh+1);
x(1)=x0;
y(1)=y0;
for j=2:1:Nh+1
    x(j) = h+x(j-1);
    g = @(s) s - y(j-1) -  h*fun(x(j),s);
    y(j) = fsolve(g,y(j-1));
end
end


