% ----------------------------------------------------------------
% FRK4: Resuelve ecuaciones diferenciales del tipo
% y' = f(x,y) usando un
% mtodo de Runge-Kutta de cuarto orden utilizando una malla
% equiespaciada con Nh intervalos.
%
% PARMETROS DE ENTRADA:
% fun: puntero a funcin. Es importante que la funcin est definida como
% una funcin de dos variables f(x,y,k1,k2,..,kn) por este orden.
% k1,k2,..,kn son todos los otros parmetros que puede haber en la funcin
% y que pasamos a travs de varargin.
% x0: valor inicial de la variable independiente
% xf: valor final de la variable independiente
% y0: variable con el valor inicial de y
% Nh: nmero de intervalos que tomamos entre el instante inicial y final.
% Por ejemplo, si Nh=3, dividimos el tiempo entre el instante inicial y el
% final en tres intervalos.
% varargin: los valores de los parmetros k1,k2,..,kn que puede haber en la funcin
%
% PARMETROS DE SALIDA:
% x: vector columna con los valores de la variable independiente en los que se ha
% evaluado y.
% y: vector columna con lo valores de la funcin y
% -----------------------------------------------------


function [x,y]=fRK4(fun,x0,xf,y0,Nh)
h=(xf-x0)/Nh;
x=zeros(1,Nh+1);
y=zeros(1,Nh+1);
x(1)=x0;
y(1)=y0;
hm=h*0.5;   % La mitad del paso.
for j=2:1:Nh+1
    xm=x(j-1)+h/2;
    % Primera evaluacin de f(x,y)
    f1=fun(x(j-1),y(j-1));
    ym1=y(j-1)+hm*f1;
    % Segunda evaluacin de f(x,y)
    f2 = fun(xm,ym1);
    ym2=y(j-1)+hm*f2;
    % Tercera evaluacin de f(x,y)
    f3=fun(xm,ym2);
    yj=y(j-1)+h*f3;
    % Cuarta evaluacin de f(x,y)
    x(j)=x(j-1)+h;
    f4=fun(x(j),yj);
    % El valor final de y(j).
    y(j)=y(j-1)+h*(f1/6+f2/3+f3/3+f4/6);
end
end
